def gray(text):
    return f"\u001b[90m{text}\u001b[0m"

def red(text):
    return f"\u001b[31m{text}\u001b[0m"

def cyan(text):
    return f"\u001b[36m{text}\u001b[0m"

def green(text):
    return f"\u001b[32m{text}\u001b[0m"

def yellow(text):
    return f"\u001b[33m{text}\u001b[0m"